@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Output/HTML/DashboardCustomerIDStatus.pm
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,8 +12,7 @@ package Kernel::Output::HTML::DashboardCustomerIDStatus;
 use strict;
 use warnings;
 
-#use Kernel::System::CustomerCompany;
-#use Kernel::System::Valid;
+our $ObjectManagerDisabled = 1;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -21,17 +21,11 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (
-        qw(Config Name ConfigObject LogObject DBObject LayoutObject ParamObject TicketObject UserID)
-        )
-    {
-        die "Got no $_!" if ( !$Self->{$_} );
+    # get needed parameters
+    for my $Needed (qw(Config Name UserID)) {
+        die "Got no $Needed!" if ( !$Self->{$Needed} );
     }
 
-    #    $Self->{CustomerCompanyObject} = Kernel::System::CustomerCompany->new( %{$Self} );
-    #    $Self->{ValidObject}           = Kernel::System::Valid->new( %{$Self} );
-
     $Self->{PrefKey} = 'UserDashboardPref' . $Self->{Name} . '-Shown';
 
     $Self->{CacheKey} = $Self->{Name};
@@ -62,18 +56,24 @@ sub Run {
 
     return if !$Param{CustomerID};
 
-    my $CustomerIDSQL = $Self->{DBObject}->QueryStringEscape( QueryString => $Param{CustomerID} );
+    my $CustomerIDRaw = $Param{CustomerID};
+
+    # get ticket object
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
 
     # escalated tickets
     my $Count = $Self->{TicketObject}->TicketSearch(
         TicketEscalationTimeOlderMinutes => 1,
-        CustomerID                       => $CustomerIDSQL,
+        CustomerIDRaw                    => $CustomerIDRaw,
         Result                           => 'COUNT',
         Permission                       => $Self->{Config}->{Permission},
         UserID                           => $Self->{UserID},
         CacheTTL                         => $Self->{Config}->{CacheTTLLocal} * 60,
     );
 
+    # get layout object
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     $Self->{LayoutObject}->Block(
         Name => 'ContentSmallCustomerIDStatusEscalatedTickets',
         Data => {
@@ -84,12 +84,12 @@ sub Run {
 
     # open tickets
     $Count = $Self->{TicketObject}->TicketSearch(
-        StateType  => 'Open',
-        CustomerID => $CustomerIDSQL,
-        Result     => 'COUNT',
-        Permission => $Self->{Config}->{Permission},
-        UserID     => $Self->{UserID},
-        CacheTTL   => $Self->{Config}->{CacheTTLLocal} * 60,
+        StateType     => 'Open',
+        CustomerIDRaw => $CustomerIDRaw,
+        Result        => 'COUNT',
+        Permission    => $Self->{Config}->{Permission},
+        UserID        => $Self->{UserID},
+        CacheTTL      => $Self->{Config}->{CacheTTLLocal} * 60,
     );
 
     $Self->{LayoutObject}->Block(
@@ -102,12 +102,12 @@ sub Run {
 
     # closed tickets
     $Count = $Self->{TicketObject}->TicketSearch(
-        StateType  => 'Closed',
-        CustomerID => $CustomerIDSQL,
-        Result     => 'COUNT',
-        Permission => $Self->{Config}->{Permission},
-        UserID     => $Self->{UserID},
-        CacheTTL   => $Self->{Config}->{CacheTTLLocal} * 60,
+        StateType     => 'closed',
+        CustomerIDRaw => $CustomerIDRaw,
+        Result        => 'COUNT',
+        Permission    => $Self->{Config}->{Permission},
+        UserID        => $Self->{UserID},
+        CacheTTL      => $Self->{Config}->{CacheTTLLocal} * 60,
     );
 
     $Self->{LayoutObject}->Block(
@@ -120,11 +120,11 @@ sub Run {
 
     # all tickets
     $Count = $Self->{TicketObject}->TicketSearch(
-        CustomerID => $CustomerIDSQL,
-        Result     => 'COUNT',
-        Permission => $Self->{Config}->{Permission},
-        UserID     => $Self->{UserID},
-        CacheTTL   => $Self->{Config}->{CacheTTLLocal} * 60,
+        CustomerIDRaw => $CustomerIDRaw,
+        Result        => 'COUNT',
+        Permission    => $Self->{Config}->{Permission},
+        UserID        => $Self->{UserID},
+        CacheTTL      => $Self->{Config}->{CacheTTLLocal} * 60,
     );
 
     $Self->{LayoutObject}->Block(
@@ -136,14 +136,14 @@ sub Run {
     );
 
     # archived tickets
-    if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
+    if ( $Kernel::OM->Get('Kernel::Config')->Get('Ticket::ArchiveSystem') ) {
         $Count = $Self->{TicketObject}->TicketSearch(
-            CustomerID   => $CustomerIDSQL,
-            ArchiveFlags => ['y'],
-            Result       => 'COUNT',
-            Permission   => $Self->{Config}->{Permission},
-            UserID       => $Self->{UserID},
-            CacheTTL     => $Self->{Config}->{CacheTTLLocal} * 60,
+            CustomerIDRaw => $CustomerIDRaw,
+            ArchiveFlags  => ['y'],
+            Result        => 'COUNT',
+            Permission    => $Self->{Config}->{Permission},
+            UserID        => $Self->{UserID},
+            CacheTTL      => $Self->{Config}->{CacheTTLLocal} * 60,
         );
 
         $Self->{LayoutObject}->Block(
