@@ -1,6 +1,6 @@
 # --
 # Kernel/Output/HTML/DashboardCustomerUserList.pm
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,7 +12,7 @@ package Kernel::Output::HTML::DashboardCustomerUserList;
 use strict;
 use warnings;
 
-use Kernel::System::CustomerUser;
+our $ObjectManagerDisabled = 1;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -21,26 +21,24 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (
-        qw(Config Name ConfigObject LogObject DBObject LayoutObject TicketObject ParamObject UserID GroupObject)
-        )
-    {
-        die "Got no $_!" if ( !$Self->{$_} );
+    # get needed parameters
+    for my $Needed (qw(Config Name UserID)) {
+        die "Got no $Needed!" if ( !$Self->{$Needed} );
     }
 
-    # use customer user object if it comes in the params
-    $Self->{CustomerUserObject} = $Param{CustomerUserObject}
-        // Kernel::System::CustomerUser->new( %{$Self} );
+    # get param object
+    my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
 
     # get current filter
-    my $Name = $Self->{ParamObject}->GetParam( Param => 'Name' ) || '';
+    my $Name = $ParamObject->GetParam( Param => 'Name' ) || '';
     my $PreferencesKey = 'UserDashboardCustomerUserListFilter' . $Self->{Name};
 
     $Self->{PrefKey} = 'UserDashboardPref' . $Self->{Name} . '-Shown';
 
-    $Self->{PageShown} = $Self->{LayoutObject}->{ $Self->{PrefKey} } || $Self->{Config}->{Limit};
-    $Self->{StartHit} = int( $Self->{ParamObject}->GetParam( Param => 'StartHit' ) || 1 );
+    $Self->{PageShown} = $Kernel::OM->Get('Kernel::Output::HTML::Layout')->{ $Self->{PrefKey} }
+        || $Self->{Config}->{Limit};
+
+    $Self->{StartHit} = int( $ParamObject->GetParam( Param => 'StartHit' ) || 1 );
 
     return $Self;
 }
@@ -88,28 +86,34 @@ sub Run {
 
     return if !$Param{CustomerID};
 
-    my $CustomerIDs = { $Self->{CustomerUserObject}->CustomerSearch( CustomerID => $Param{CustomerID} ) };
+    # get customer user object
+    my $CustomerUserObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
+
+    my $CustomerIDs = { $CustomerUserObject->CustomerSearch( CustomerIDRaw => $Param{CustomerID} ) };
 
     # add page nav bar
     my $Total = scalar keys %{$CustomerIDs};
 
+    # get layout object
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     my $LinkPage = 'Subaction=Element;Name='
         . $Self->{Name} . ';'
         . 'CustomerID='
-        . $Self->{LayoutObject}->LinkEncode( $Param{CustomerID} ) . ';';
+        . $LayoutObject->LinkEncode( $Param{CustomerID} ) . ';';
 
-    my %PageNav = $Self->{LayoutObject}->PageNavBar(
+    my %PageNav = $LayoutObject->PageNavBar(
         StartHit       => $Self->{StartHit},
         PageShown      => $Self->{PageShown},
         AllHits        => $Total || 1,
-        Action         => 'Action=' . $Self->{LayoutObject}->{Action},
+        Action         => 'Action=' . $LayoutObject->{Action},
         Link           => $LinkPage,
         AJAXReplace    => 'Dashboard' . $Self->{Name},
         IDPrefix       => 'Dashboard' . $Self->{Name},
         KeepScriptTags => $Param{AJAX},
     );
 
-    $Self->{LayoutObject}->Block(
+    $LayoutObject->Block(
         Name => 'ContentLargeCustomerUserListNavBar',
         Data => {
             %{ $Self->{Config} },
@@ -118,16 +122,22 @@ sub Run {
         },
     );
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # check the permission for the SwitchToCustomer feature
-    if ( $Self->{ConfigObject}->Get('SwitchToCustomer') ) {
+    if ( $ConfigObject->Get('SwitchToCustomer') ) {
+
+        # get group object
+        my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
 
         # get the group id which is allowed to use the switch to customer feature
-        my $SwitchToCustomerGroupID = $Self->{GroupObject}->GroupLookup(
-            Group => $Self->{ConfigObject}->Get('SwitchToCustomer::PermissionGroup'),
+        my $SwitchToCustomerGroupID = $GroupObject->GroupLookup(
+            Group => $ConfigObject->Get('SwitchToCustomer::PermissionGroup'),
         );
 
         # get user groups, where the user has the rw privilege
-        my %Groups = $Self->{GroupObject}->GroupMemberList(
+        my %Groups = $GroupObject->GroupMemberList(
             UserID => $Self->{UserID},
             Type   => 'rw',
             Result => 'HASH',
@@ -138,7 +148,7 @@ sub Run {
 
             $Self->{SwitchToCustomerPermission} = 1;
 
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'OverviewResultSwitchToCustomer',
             );
         }
@@ -146,18 +156,18 @@ sub Run {
 
     # show add new customer button if there are writable customer backends and if
     # the agent has permission
-    my $AddAccess = $Self->{LayoutObject}->Permission(
+    my $AddAccess = $LayoutObject->Permission(
         Action => 'AdminCustomerUser',
         Type   => 'rw',                  # ro|rw possible
     );
 
     # get writable data sources
-    my %CustomerSource = $Self->{CustomerUserObject}->CustomerSourceList(
+    my %CustomerSource = $CustomerUserObject->CustomerSourceList(
         ReadOnly => 0,
     );
 
     if ( $AddAccess && scalar keys %CustomerSource ) {
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ContentLargeCustomerUserAdd',
             Data => {
                 CustomerID => $Self->{CustomerID},
@@ -166,27 +176,27 @@ sub Run {
     }
 
     # get the permission for the phone ticket creation
-    my $NewAgentTicketPhonePermission = $Self->{LayoutObject}->Permission(
+    my $NewAgentTicketPhonePermission = $LayoutObject->Permission(
         Action => 'AgentTicketPhone',
         Type   => 'rw',
     );
 
     # check the permission for the phone ticket creation
     if ($NewAgentTicketPhonePermission) {
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'OverviewResultNewAgentTicketPhone',
         );
     }
 
     # get the permission for the email ticket creation
-    my $NewAgentTicketEmailPermission = $Self->{LayoutObject}->Permission(
+    my $NewAgentTicketEmailPermission = $LayoutObject->Permission(
         Action => 'AgentTicketEmail',
         Type   => 'rw',
     );
 
     # check the permission for the email ticket creation
     if ($NewAgentTicketEmailPermission) {
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'OverviewResultNewAgentTicketEmail',
         );
     }
@@ -195,7 +205,7 @@ sub Run {
     @CustomerKeys = splice @CustomerKeys, $Self->{StartHit} - 1, $Self->{PageShown};
 
     for my $CustomerKey (@CustomerKeys) {
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ContentLargeCustomerUserListRow',
             Data => {
                 %Param,
@@ -206,7 +216,7 @@ sub Run {
 
         # can edit?
         if ( $AddAccess && scalar keys %CustomerSource ) {
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'ContentLargeCustomerUserListRowCustomerKeyLink',
                 Data => {
                     %Param,
@@ -216,7 +226,7 @@ sub Run {
             );
         }
         else {
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'ContentLargeCustomerUserListRowCustomerKeyText',
                 Data => {
                     %Param,
@@ -226,49 +236,100 @@ sub Run {
             );
         }
 
-        my $CustomerKeySQL = $Self->{DBObject}->QueryStringEscape( QueryString => $CustomerKey );
+        # do we need to show the chat link?
+        # should only be visible if
+        # 1. chat is active
+        # 2. current user has access to the chat
+        # 3. this customer user is online
+        my $ChatStartingAgentsGroup
+            = $Kernel::OM->Get('Kernel::Config')->Get('ChatEngine::PermissionGroup::ChatStartingAgents');
 
-        my $TicketCountOpen = $Self->{TicketObject}->TicketSearch(
-            StateType         => 'Open',
-            CustomerUserLogin => $CustomerKeySQL,
-            Result            => 'COUNT',
-            Permission        => $Self->{Config}->{Permission},
-            UserID            => $Self->{UserID},
-            CacheTTL          => $Self->{Config}->{CacheTTLLocal} * 60,
+        if (
+            $Kernel::OM->Get('Kernel::Config')->Get('ChatEngine::Active')
+            && defined $LayoutObject->{"UserIsGroup[$ChatStartingAgentsGroup]"}
+            && $LayoutObject->{"UserIsGroup[$ChatStartingAgentsGroup]"} eq 'Yes'
+            && $Kernel::OM->Get('Kernel::Config')->Get('ChatEngine::ChatDirection::AgentToCustomer')
+            )
+        {
+
+            # check if this customer is actually online
+            my $SessionObject    = $Kernel::OM->Get('Kernel::System::AuthSession');
+            my @Sessions         = $SessionObject->GetAllSessionIDs();
+            my $CustomerIsOnline = 0;
+
+            SESSIONID:
+            for my $SessionID (@Sessions) {
+
+                next SESSIONID if !$SessionID;
+
+                # get session data
+                my %Data = $SessionObject->GetSessionIDData( SessionID => $SessionID );
+
+                next SESSIONID if !%Data;
+                next SESSIONID if !$Data{UserID};
+                next SESSIONID if $Data{UserID} ne $CustomerKey;
+
+                $CustomerIsOnline = 1;
+            }
+
+            if ($CustomerIsOnline) {
+
+                my $UserFullname = $Kernel::OM->Get('Kernel::System::CustomerUser')->CustomerName(
+                    UserLogin => $CustomerKey,
+                );
+
+                $LayoutObject->Block(
+                    Name => 'ContentLargeCustomerUserListRowCustomerKeyChatStart',
+                    Data => {
+                        UserFullname => $UserFullname,
+                        UserID       => $CustomerKey,
+                    },
+                );
+            }
+        }
+
+        # get ticket object
+        my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
+        my $TicketCountOpen = $TicketObject->TicketSearch(
+            StateType            => 'Open',
+            CustomerUserLoginRaw => $CustomerKey,
+            Result               => 'COUNT',
+            Permission           => $Self->{Config}->{Permission},
+            UserID               => $Self->{UserID},
+            CacheTTL             => $Self->{Config}->{CacheTTLLocal} * 60,
         );
 
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ContentLargeCustomerUserListRowCustomerUserTicketsOpen',
             Data => {
                 %Param,
-                Count          => $TicketCountOpen,
-                CustomerKey    => $CustomerKey,
-                CustomerKeySQL => $CustomerKeySQL,
+                Count       => $TicketCountOpen,
+                CustomerKey => $CustomerKey,
             },
         );
 
-        my $TicketCountClosed = $Self->{TicketObject}->TicketSearch(
-            StateType         => 'Closed',
-            CustomerUserLogin => $CustomerKeySQL,
-            Result            => 'COUNT',
-            Permission        => $Self->{Config}->{Permission},
-            UserID            => $Self->{UserID},
-            CacheTTL          => $Self->{Config}->{CacheTTLLocal} * 60,
+        my $TicketCountClosed = $TicketObject->TicketSearch(
+            StateType            => 'Closed',
+            CustomerUserLoginRaw => $CustomerKey,
+            Result               => 'COUNT',
+            Permission           => $Self->{Config}->{Permission},
+            UserID               => $Self->{UserID},
+            CacheTTL             => $Self->{Config}->{CacheTTLLocal} * 60,
         );
 
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ContentLargeCustomerUserListRowCustomerUserTicketsClosed',
             Data => {
                 %Param,
-                Count          => $TicketCountClosed,
-                CustomerKey    => $CustomerKey,
-                CustomerKeySQL => $CustomerKeySQL,
+                Count       => $TicketCountClosed,
+                CustomerKey => $CustomerKey,
             },
         );
 
         # check the permission for the phone ticket creation
         if ($NewAgentTicketPhonePermission) {
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'ContentLargeCustomerUserListNewAgentTicketPhone',
                 Data => {
                     %Param,
@@ -280,7 +341,7 @@ sub Run {
 
         # check the permission for the email ticket creation
         if ($NewAgentTicketEmailPermission) {
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'ContentLargeCustomerUserListNewAgentTicketEmail',
                 Data => {
                     %Param,
@@ -290,15 +351,14 @@ sub Run {
             );
         }
 
-        if ( $Self->{ConfigObject}->Get('SwitchToCustomer') && $Self->{SwitchToCustomerPermission} )
+        if ( $ConfigObject->Get('SwitchToCustomer') && $Self->{SwitchToCustomerPermission} )
         {
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'OverviewResultRowSwitchToCustomer',
                 Data => {
                     %Param,
-                    Count          => $TicketCountClosed,
-                    CustomerKey    => $CustomerKey,
-                    CustomerKeySQL => $CustomerKeySQL,
+                    Count       => $TicketCountClosed,
+                    CustomerKey => $CustomerKey,
                 },
             );
         }
@@ -306,7 +366,7 @@ sub Run {
 
     # show "none" if there are no customers
     if ( !%{$CustomerIDs} ) {
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ContentLargeCustomerUserListNone',
             Data => {},
         );
@@ -318,7 +378,7 @@ sub Run {
         $Refresh = 60 * $Self->{UserRefreshTime};
         my $NameHTML = $Self->{Name};
         $NameHTML =~ s{-}{_}xmsg;
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ContentLargeTicketGenericRefresh',
             Data => {
                 %{ $Self->{Config} },
@@ -330,7 +390,7 @@ sub Run {
         );
     }
 
-    my $Content = $Self->{LayoutObject}->Output(
+    my $Content = $LayoutObject->Output(
         TemplateFile => 'AgentDashboardCustomerUserList',
         Data         => {
             %{ $Self->{Config} },
