@@ -1,6 +1,6 @@
 # --
 # Kernel/Output/HTML/DashboardImage.pm
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +12,11 @@ package Kernel::Output::HTML::DashboardImage;
 use strict;
 use warnings;
 
+# prevent 'Used once' warning
+use Kernel::System::ObjectManager;
+
+our $ObjectManagerDisabled = 1;
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -19,12 +24,9 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (
-        qw(Config Name ConfigObject LogObject DBObject LayoutObject ParamObject TicketObject UserID)
-        )
-    {
-        die "Got no $_!" if ( !$Self->{$_} );
+    # get needed parameters
+    for my $Needed (qw(Config Name UserID)) {
+        die "Got no $Needed!" if ( !$Self->{$Needed} );
     }
 
     return $Self;
@@ -47,7 +49,7 @@ sub Config {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $Content = $Self->{LayoutObject}->Output(
+    my $Content = $Kernel::OM->Get('Kernel::Output::HTML::Layout')->Output(
         TemplateFile => 'AgentDashboardImage',
         Data         => {
             %{ $Self->{Config} },
