@@ -1,6 +1,6 @@
 # --
 # Kernel/System/SLA.pm - all sla functions
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,8 +12,14 @@ package Kernel::System::SLA;
 use strict;
 use warnings;
 
-use Kernel::System::CheckItem;
-use Kernel::System::Valid;
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Cache',
+    'Kernel::System::CheckItem',
+    'Kernel::System::DB',
+    'Kernel::System::Log',
+    'Kernel::System::Valid',
+);
 
 =head1 NAME
 
@@ -31,41 +37,11 @@ All sla functions.
 
 =item new()
 
-create an object
+create an object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::SLA;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $SLAObject = Kernel::System::SLA->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        DBObject     => $DBObject,
-        MainObject   => $MainObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $SLAObject = $Kernel::OM->Get('Kernel::System::SLA');
 
 =cut
 
@@ -76,19 +52,15 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for my $Object (qw(DBObject ConfigObject EncodeObject LogObject MainObject)) {
-        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
-    }
-    $Self->{CheckItemObject} = Kernel::System::CheckItem->new( %{$Self} );
-    $Self->{ValidObject}     = Kernel::System::Valid->new( %{$Self} );
-
-    # load generator preferences module
-    my $GeneratorModule = $Self->{ConfigObject}->Get('SLA::PreferencesModule')
+    # get configured preferences object
+    my $GeneratorModule = $Kernel::OM->Get('Kernel::Config')->Get('SLA::PreferencesModule')
         || 'Kernel::System::SLA::PreferencesDB';
-    if ( $Self->{MainObject}->Require($GeneratorModule) ) {
-        $Self->{PreferencesObject} = $GeneratorModule->new( %{$Self} );
-    }
+
+    # get preferences object
+    $Self->{PreferencesObject} = $Kernel::OM->Get($GeneratorModule);
+
+    $Self->{CacheType} = 'SLA';
+    $Self->{CacheTTL}  = 60 * 60 * 24 * 20;
 
     return $Self;
 }
@@ -110,7 +82,7 @@ sub SLAList {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need UserID!'
         );
@@ -122,6 +94,9 @@ sub SLAList {
         $Param{Valid} = 1;
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # add ServiceID
     my %SQLTable;
     $SQLTable{sla} = 'sla s';
@@ -129,7 +104,7 @@ sub SLAList {
     if ( $Param{ServiceID} ) {
 
         # quote
-        $Param{ServiceID} = $Self->{DBObject}->Quote( $Param{ServiceID}, 'Integer' );
+        $Param{ServiceID} = $DBObject->Quote( $Param{ServiceID}, 'Integer' );
 
         $SQLTable{service} = 'service_sla r';
         push @SQLWhere, "s.id = r.sla_id AND r.service_id = $Param{ServiceID}";
@@ -138,8 +113,11 @@ sub SLAList {
     # add valid part
     if ( $Param{Valid} ) {
 
+        # get valid object
+        my $ValidObject = $Kernel::OM->Get('Kernel::System::Valid');
+
         # create the valid list
-        my $ValidIDs = join ', ', $Self->{ValidObject}->ValidIDsGet();
+        my $ValidIDs = join ', ', $ValidObject->ValidIDsGet();
 
         push @SQLWhere, "s.valid_id IN ( $ValidIDs )";
     }
@@ -149,13 +127,13 @@ sub SLAList {
     my $WhereString = @SQLWhere ? ' WHERE ' . join q{ AND }, @SQLWhere : '';
 
     # ask database
-    $Self->{DBObject}->Prepare(
+    $DBObject->Prepare(
         SQL => "SELECT s.id, s.name FROM $TableString $WhereString",
     );
 
     # fetch the result
     my %SLAList;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $SLAList{ $Row[0] } = $Row[1];
     }
 
@@ -204,9 +182,9 @@ sub SLAGet {
     # check needed stuff
     for my $Argument (qw(SLAID UserID)) {
         if ( !$Param{$Argument} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $Argument!"
+                Message  => "Need $Argument!",
             );
             return;
         }
@@ -214,12 +192,22 @@ sub SLAGet {
 
     # check if result is already cached
     my $CacheKey = 'Cache::SLAGet::' . $Param{SLAID};
-    if ( $Self->{$CacheKey} ) {
-        return %{ $Self->{$CacheKey} };
+    my $Cached   = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type           => $Self->{CacheType},
+        Key            => $CacheKey,
+        CacheInMemory  => 1,
+        CacheInBackend => 0,
+    );
+
+    if ( ref $Cached eq 'HASH' ) {
+        return %{$Cached};
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # get sla from db
-    $Self->{DBObject}->Prepare(
+    $DBObject->Prepare(
         SQL => 'SELECT id, name, calendar_name, first_response_time, first_response_notify, '
             . 'update_time, update_notify, solution_time, solution_notify, '
             . 'valid_id, comments, create_time, create_by, change_time, change_by '
@@ -232,7 +220,7 @@ sub SLAGet {
 
     # fetch the result
     my %SLAData;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $SLAData{SLAID}               = $Row[0];
         $SLAData{Name}                = $Row[1];
         $SLAData{Calendar}            = $Row[2] || '';
@@ -252,7 +240,7 @@ sub SLAGet {
 
     # check sla
     if ( !$SLAData{SLAID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "No such SLAID ($Param{SLAID})!",
         );
@@ -260,14 +248,14 @@ sub SLAGet {
     }
 
     # get all service ids
-    $Self->{DBObject}->Prepare(
+    $DBObject->Prepare(
         SQL  => 'SELECT service_id FROM service_sla WHERE sla_id = ? ORDER BY service_id ASC',
         Bind => [ \$SLAData{SLAID} ],
     );
 
     # fetch the result
     my @ServiceIDs;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         push @ServiceIDs, $Row[0];
     }
 
@@ -282,8 +270,17 @@ sub SLAGet {
         %SLAData = ( %SLAData, %Preferences );
     }
 
-    # cache the result
-    $Self->{$CacheKey} = \%SLAData;
+    # cache result
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+        Type => $Self->{CacheType},
+        TTL  => $Self->{CacheTTL},
+        Key  => $CacheKey,
+
+        # make a local copy of the sla data to avoid it being altered in-memory later
+        Value          => {%SLAData},
+        CacheInMemory  => 1,
+        CacheInBackend => 0,
+    );
 
     return %SLAData;
 }
@@ -309,36 +306,52 @@ sub SLALookup {
 
     # check needed stuff
     if ( !$Param{SLAID} && !$Param{Name} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need SLAID or Name!',
         );
         return;
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     if ( $Param{SLAID} ) {
 
         # check cache
         my $CacheKey = 'Cache::SLALookup::ID::' . $Param{SLAID};
-        if ( defined $Self->{$CacheKey} ) {
-            return $Self->{$CacheKey};
+        my $Cached   = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+            Type           => $Self->{CacheType},
+            Key            => $CacheKey,
+            CacheInMemory  => 1,
+            CacheInBackend => 0,
+        );
+        if ( defined $Cached ) {
+            return $Cached;
         }
 
         # lookup
-        $Self->{DBObject}->Prepare(
+        $DBObject->Prepare(
             SQL   => 'SELECT name FROM sla WHERE id = ?',
             Bind  => [ \$Param{SLAID}, ],
             Limit => 1,
         );
 
         # fetch the result
-        my $Name;
-        while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        my $Name = '';
+        while ( my @Row = $DBObject->FetchrowArray() ) {
             $Name = $Row[0];
         }
 
         # cache
-        $Self->{$CacheKey} = $Name;
+        $Kernel::OM->Get('Kernel::System::Cache')->Set(
+            Type           => $Self->{CacheType},
+            TTL            => $Self->{CacheTTL},
+            Key            => $CacheKey,
+            Value          => $Name,
+            CacheInMemory  => 1,
+            CacheInBackend => 0,
+        );
 
         return $Name;
     }
@@ -346,25 +359,38 @@ sub SLALookup {
 
         # check cache
         my $CacheKey = 'Cache::SLALookup::Name::' . $Param{Name};
-        if ( defined $Self->{$CacheKey} ) {
-            return $Self->{$CacheKey};
+        my $Cached   = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+            Type           => $Self->{CacheType},
+            Key            => $CacheKey,
+            CacheInMemory  => 1,
+            CacheInBackend => 0,
+        );
+        if ( defined $Cached ) {
+            return $Cached;
         }
 
         # lookup
-        $Self->{DBObject}->Prepare(
+        $DBObject->Prepare(
             SQL   => 'SELECT id FROM sla WHERE name = ?',
             Bind  => [ \$Param{Name} ],
             Limit => 1,
         );
 
         # fetch the result
-        my $SLAID;
-        while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        my $SLAID = '';
+        while ( my @Row = $DBObject->FetchrowArray() ) {
             $SLAID = $Row[0];
         }
 
         # cache
-        $Self->{$CacheKey} = $SLAID;
+        $Kernel::OM->Get('Kernel::System::Cache')->Set(
+            Type           => $Self->{CacheType},
+            TTL            => $Self->{CacheTTL},
+            Key            => $CacheKey,
+            Value          => $SLAID,
+            CacheInMemory  => 1,
+            CacheInBackend => 0,
+        );
 
         return $SLAID;
     }
@@ -397,7 +423,7 @@ sub SLAAdd {
     # check needed stuff
     for my $Argument (qw(Name ValidID UserID)) {
         if ( !$Param{$Argument} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Argument!",
             );
@@ -407,7 +433,7 @@ sub SLAAdd {
 
     # check service ids
     if ( defined $Param{ServiceIDs} && ref $Param{ServiceIDs} ne 'ARRAY' ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'ServiceIDs needs to be an array reference!',
         );
@@ -425,17 +451,23 @@ sub SLAAdd {
     $Param{SolutionTime}        ||= 0;
     $Param{SolutionNotify}      ||= 0;
 
+    # get check item object
+    my $CheckItemObject = $Kernel::OM->Get('Kernel::System::CheckItem');
+
     # cleanup given params
     for my $Argument (qw(Name Comment)) {
-        $Self->{CheckItemObject}->StringClean(
+        $CheckItemObject->StringClean(
             StringRef         => \$Param{$Argument},
             RemoveAllNewlines => 1,
             RemoveAllTabs     => 1,
         );
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # find exiting sla's with the same name
-    $Self->{DBObject}->Prepare(
+    $DBObject->Prepare(
         SQL   => 'SELECT id FROM sla WHERE name = ?',
         Bind  => [ \$Param{Name} ],
         Limit => 1,
@@ -443,13 +475,13 @@ sub SLAAdd {
 
     # fetch the result
     my $NoAdd;
-    while ( $Self->{DBObject}->FetchrowArray() ) {
+    while ( $DBObject->FetchrowArray() ) {
         $NoAdd = 1;
     }
 
     # abort insert of new sla, if name already exists
     if ($NoAdd) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't add new SLA! '$Param{Name}' already exists.",
         );
@@ -457,7 +489,7 @@ sub SLAAdd {
     }
 
     # add sla to database
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL => 'INSERT INTO sla '
             . '(name, calendar_name, first_response_time, first_response_notify, '
             . 'update_time, update_notify, solution_time, solution_notify, '
@@ -472,7 +504,7 @@ sub SLAAdd {
     );
 
     # get sla id
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL   => 'SELECT id FROM sla WHERE name = ?',
         Bind  => [ \$Param{Name} ],
         Limit => 1,
@@ -480,13 +512,13 @@ sub SLAAdd {
 
     # fetch the result
     my $SLAID;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $SLAID = $Row[0];
     }
 
     # check sla id
     if ( !$SLAID ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't find SLAID for '$Param{Name}'!",
         );
@@ -494,7 +526,7 @@ sub SLAAdd {
     }
 
     # remove all existing allocations
-    $Self->{DBObject}->Do(
+    $DBObject->Do(
         SQL  => 'DELETE FROM service_sla WHERE sla_id = ?',
         Bind => [ \$SLAID ],
     );
@@ -503,7 +535,7 @@ sub SLAAdd {
     for my $ServiceID ( @{ $Param{ServiceIDs} } ) {
 
         # add one allocation
-        $Self->{DBObject}->Do(
+        $DBObject->Do(
             SQL  => 'INSERT INTO service_sla (service_id, sla_id) VALUES (?, ?)',
             Bind => [ \$ServiceID, \$SLAID ],
         );
@@ -540,7 +572,7 @@ sub SLAUpdate {
     # check needed stuff
     for my $Argument (qw(SLAID Name ValidID UserID)) {
         if ( !$Param{$Argument} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Argument!",
             );
@@ -550,7 +582,7 @@ sub SLAUpdate {
 
     # check service ids
     if ( defined $Param{ServiceIDs} && ref $Param{ServiceIDs} ne 'ARRAY' ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'ServiceIDs need to be an array reference!',
         );
@@ -568,17 +600,23 @@ sub SLAUpdate {
     $Param{SolutionTime}        ||= 0;
     $Param{SolutionNotify}      ||= 0;
 
+    # get check item object
+    my $CheckItemObject = $Kernel::OM->Get('Kernel::System::CheckItem');
+
     # cleanup given params
     for my $Argument (qw(Name Comment)) {
-        $Self->{CheckItemObject}->StringClean(
+        $CheckItemObject->StringClean(
             StringRef         => \$Param{$Argument},
             RemoveAllNewlines => 1,
             RemoveAllTabs     => 1,
         );
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # find exiting sla's with the same name
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL   => 'SELECT id FROM sla WHERE name = ?',
         Bind  => [ \$Param{Name} ],
         Limit => 1,
@@ -586,7 +624,7 @@ sub SLAUpdate {
 
     # fetch the result
     my $Update = 0;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[0] != $Param{SLAID} ) {
             $Update = $Row[0];
         }
@@ -594,7 +632,7 @@ sub SLAUpdate {
 
     # abort update of sla, if name already exists
     if ($Update) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't update SLA! '$Param{Name}' already exists.",
         );
@@ -602,12 +640,21 @@ sub SLAUpdate {
     }
 
     # reset cache
-    delete $Self->{ 'Cache::SLAGet::' . $Param{SLAID} };
-    delete $Self->{ 'Cache::SLALookup::Name::' . $Param{Name} };
-    delete $Self->{ 'Cache::SLALookup::ID::' . $Param{SLAID} };
+    $Kernel::OM->Get('Kernel::System::Cache')->Delete(
+        Type => $Self->{CacheType},
+        Key  => 'Cache::SLAGet::' . $Param{SLAID},
+    );
+    $Kernel::OM->Get('Kernel::System::Cache')->Delete(
+        Type => $Self->{CacheType},
+        Key  => 'Cache::SLALookup::Name::' . $Param{Name},
+    );
+    $Kernel::OM->Get('Kernel::System::Cache')->Delete(
+        Type => $Self->{CacheType},
+        Key  => 'Cache::SLALookup::ID::' . $Param{SLAID},
+    );
 
     # update service
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL => 'UPDATE sla SET name = ?, calendar_name = ?, '
             . 'first_response_time = ?, first_response_notify = ?, '
             . 'update_time = ?, update_notify = ?, solution_time = ?, solution_notify = ?, '
@@ -622,7 +669,7 @@ sub SLAUpdate {
     );
 
     # remove all existing allocations
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL  => 'DELETE FROM service_sla WHERE sla_id = ?',
         Bind => [ \$Param{SLAID}, ]
     );
@@ -631,7 +678,7 @@ sub SLAUpdate {
     for my $ServiceID ( @{ $Param{ServiceIDs} } ) {
 
         # add one allocation
-        return if !$Self->{DBObject}->Do(
+        return if !$DBObject->Do(
             SQL  => 'INSERT INTO service_sla (service_id, sla_id) VALUES (?, ?)',
             Bind => [ \$ServiceID, \$Param{SLAID} ],
         );
