@@ -1,4 +1,6 @@
 # --
+# Kernel/System/Ticket/Acl/CloseParentAfterClosedChilds.pm - acl module
+# - allow no parent close till all clients are closed -
 # Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
@@ -11,7 +13,11 @@ package Kernel::System::Ticket::Acl::CloseParentAfterClosedChilds;
 use strict;
 use warnings;
 
-use Kernel::System::LinkObject;
+our @ObjectDependencies = (
+    'Kernel::System::LinkObject',
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -20,14 +26,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (
-        qw(ConfigObject DBObject TicketObject LogObject UserObject CustomerUserObject MainObject TimeObject EncodeObject)
-        )
-    {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
-
     return $Self;
 }
 
@@ -37,7 +35,7 @@ sub Run {
     # check needed stuff
     for (qw(Config Acl)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -48,16 +46,8 @@ sub Run {
     # check if child tickets are not closed
     return 1 if !$Param{TicketID} || !$Param{UserID};
 
-    # create new instance of the link object
-    if ( !$Self->{LinkObject} ) {
-        $Self->{LinkObject} = Kernel::System::LinkObject->new(
-            %{$Self},
-            %Param,
-        );
-    }
-
     # link tickets
-    my $Links = $Self->{LinkObject}->LinkList(
+    my $Links = $Kernel::OM->Get('Kernel::System::LinkObject')->LinkList(
         Object => 'Ticket',
         Key    => $Param{TicketID},
         State  => 'Valid',
@@ -79,7 +69,7 @@ sub Run {
     for my $TicketID ( sort keys %{ $Links->{Ticket}->{ParentChild}->{Target} } ) {
 
         # get ticket
-        my %Ticket = $Self->{TicketObject}->TicketGet(
+        my %Ticket = $Kernel::OM->Get('Kernel::System::Ticket')->TicketGet(
             TicketID      => $TicketID,
             DynamicFields => 0,
         );
@@ -92,6 +82,7 @@ sub Run {
 
     # generate acl
     if ($OpenSubTickets) {
+
         $Param{Acl}->{CloseParentAfterClosedChilds} = {
 
             # match properties
@@ -110,32 +101,7 @@ sub Run {
                 Ticket => {
                     State => $Param{Config}->{State},
                 },
-            },
-
-            # return possible options (white list)
-            Possible => {
-
-                # possible action options
-                Action => {
-                    AgentTicketLock        => 1,
-                    AgentTicketZoom        => 1,
-                    AgentTicketClose       => 0,
-                    AgentTicketPending     => 1,
-                    AgentTicketNote        => 1,
-                    AgentTicketHistory     => 1,
-                    AgentTicketPriority    => 1,
-                    AgentTicketFreeText    => 1,
-                    AgentTicketHistory     => 1,
-                    AgentTicketCompose     => 1,
-                    AgentTicketBounce      => 1,
-                    AgentTicketForward     => 1,
-                    AgentLinkObject        => 1,
-                    AgentTicketPrint       => 1,
-                    AgentTicketPhone       => 1,
-                    AgentTicketCustomer    => 1,
-                    AgentTicketOwner       => 1,
-                    AgentTicketResponsible => 1,
-                },
+                Action => ['AgentTicketClose'],
             },
         };
     }
