@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Ticket/Event/ForceState.pm - set state
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +12,11 @@ package Kernel::System::Ticket::Event::ForceState;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::System::Log',
+    'Kernel::System::Ticket',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -19,14 +24,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (
-        qw(ConfigObject TicketObject LogObject UserObject CustomerUserObject SendmailObject TimeObject EncodeObject)
-        )
-    {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
-
     return $Self;
 }
 
@@ -36,18 +33,27 @@ sub Run {
     # check needed stuff
     for (qw(Data Event Config)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
             return;
         }
     }
     for (qw(TicketID)) {
         if ( !$Param{Data}->{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_ in Data!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $_ in Data!"
+            );
             return;
         }
     }
 
-    my %Ticket = $Self->{TicketObject}->TicketGet(
+    # get ticket object
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
+    my %Ticket = $TicketObject->TicketGet(
         TicketID      => $Param{Data}->{TicketID},
         UserID        => $Param{UserID},
         DynamicFields => 0,
@@ -57,17 +63,20 @@ sub Run {
     return 1 if lc $Ticket{Lock} ne 'lock';
 
     # set now state
+    OLDSTATE:
     for my $OldState ( sort keys %{ $Param{Config} } ) {
-        next if !$OldState;
-        next if $OldState ne $Ticket{State};
 
-        $Self->{TicketObject}->TicketStateSet(
+        next OLDSTATE if !$OldState;
+        next OLDSTATE if $OldState ne $Ticket{State};
+
+        $TicketObject->TicketStateSet(
             TicketID           => $Param{Data}->{TicketID},
             State              => $Param{Config}->{$OldState},
             SendNoNotification => 1,
             UserID             => 1,
         );
     }
+
     return 1;
 }
 
