@@ -915,7 +915,7 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
                                  FieldConfig.Config.ArticleType = $('#ArticleType').val();
 
                                  // show error if internal article type is set for an interface different than AgentInterface
-                                 if ($('#Interface').val() !== 'AgentInterface' && $('#ArticleType').val().match(/int/i)){
+                                 if ($('#Interface').val() !== 'AgentInterface' && $('#ArticleType').val().match(/-int/i)){
                                      window.alert(Core.Agent.Admin.ProcessManagement.Localization.WrongArticleTypeMsg);
                                      return;
                                  }
@@ -1256,9 +1256,9 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
     TargetNS.HideOverlay = function () {
         $('#Overlay').remove();
         $('body').css({
-            'overflow': 'auto'
+            'overflow': 'visible',
+            'min-height': 0
         });
-        $('body').css('min-height', 'auto');
     };
 
     TargetNS.GetConditionConfig = function ($Conditions) {
@@ -1301,6 +1301,12 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             return false;
         }
 
+        // IE (11) has some permission problems with objects from other windows
+        // Therefore we "copy" the object if we are in IE
+        if ($.browser.trident) {
+            Config = Core.JSON.Parse(Core.JSON.Stringify(Config));
+        }
+
         // Update config from e.g. popup windows
 
         // Update Process
