@@ -1,6 +1,6 @@
 // --
 // Core.Customer.js - provides functions for the customer login
-// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -21,9 +21,6 @@ Core.Customer = (function (TargetNS) {
     if (!Core.Debug.CheckDependency('Core.Customer', 'Core.UI', 'Core.UI')) {
         return;
     }
-    if (!Core.Debug.CheckDependency('Core.Customer', 'Core.UI.IE7Fixes', 'Core.UI.IE7Fixes')) {
-        return;
-    }
     if (!Core.Debug.CheckDependency('Core.Customer', 'Core.Form', 'Core.Form')) {
         return;
     }
@@ -34,6 +31,9 @@ Core.Customer = (function (TargetNS) {
         return;
     }
 
+    TargetNS.SupportedBrowser = true;
+    TargetNS.IECompatibilityMode = false;
+
     /**
      * @function
      * @return nothing
@@ -42,18 +42,38 @@ Core.Customer = (function (TargetNS) {
     TargetNS.Init = function () {
         var $TableElements = $('table.Overview tbody tr');
 
+        TargetNS.SupportedBrowser = Core.App.BrowserCheck('Customer');
+        TargetNS.IECompatibilityMode = Core.App.BrowserCheckIECompatibilityMode();
+
+        if (TargetNS.IECompatibilityMode) {
+            TargetNS.SupportedBrowser = false;
+            alert(Core.Config.Get('TurnOffCompatibilityModeMsg'));
+        }
+
+        if (!TargetNS.SupportedBrowser) {
+            alert(
+                Core.Config.Get('BrowserTooOldMsg')
+                + ' '
+                + Core.Config.Get('BrowserListMsg')
+                + ' '
+                + Core.Config.Get('BrowserDocumentationMsg')
+            );
+        }
+
         Core.Exception.Init();
 
         Core.Form.Validate.Init();
+        Core.UI.Popup.Init();
         // Add table functions here (because of performance reasons only do this if table has not more than 200 rows)
         if ($TableElements.length < 200) {
             $TableElements.filter(':nth-child(even)').addClass('Even');
         }
         // late execution of accessibility code
         Core.UI.Accessibility.Init();
-        // init IE7 compat code (will only run on IE7)
-        Core.UI.IE7Fixes.InitIE7InputFocus('Focus');
-        Core.UI.IE7Fixes.InitIE7InputReadonly('Readonly');
+
+        // Init tree selection/tree view for dynamic fields
+        Core.UI.TreeSelection.InitTreeSelection();
+        Core.UI.TreeSelection.InitDynamicFieldTreeViewRestore();
     };
 
     /**
