@@ -1,9 +1,10 @@
 // --
-// Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+// Core.UI.Autocomplete.js - Autocomplete functions
+// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (GPL). If you
-// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+// the enclosed file COPYING for license information (AGPL). If you
+// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 // --
 
 "use strict";
@@ -12,66 +13,22 @@ var Core = Core || {};
 Core.UI = Core.UI || {};
 
 /**
- * @namespace Core.UI.Autocomplete
- * @memberof Core.UI
- * @author OTRS AG
+ * @namespace
+ * @exports TargetNS as Core.UI.Autocomplete
  * @description
  *      This namespace contains autocomplete specific functions.
  */
 Core.UI.Autocomplete = (function (TargetNS) {
-    /**
-     * @private
-     * @name ConfigFallback
-     * @memberof Core.UI.Autocomplete
-     * @member {Object}
-     * @description
-     *      The configuration fallback values.
-     */
     var ConfigFallback = {
             AutoCompleteActive: 1,
             MinQueryLength: 2,
             QueryDelay: 100,
             MaxResultsDisplayed: 20
         },
-    /**
-     * @private
-     * @name ConfigElements
-     * @memberof Core.UI.Autocomplete
-     * @member {Object}
-     * @description
-     *      The possible config parameters.
-     */
         ConfigElements = ['AutoCompleteActive', 'MinQueryLength', 'QueryDelay', 'MaxResultsDisplayed', 'ButtonText'],
-    /**
-     * @private
-     * @name Config
-     * @memberof Core.UI.Autocomplete
-     * @member {Object}
-     * @description
-     *      The actual config, after merging the fallback values.
-     */
         Config = {},
-    /**
-     * @private
-     * @name AJAXLoaderPrefix
-     * @memberof Core.UI.Autocomplete
-     * @member {String}
-     * @description
-     *      AJAXLoaderPrefix
-     */
         AJAXLoaderPrefix = 'AJAXLoader';
 
-    /**
-     * @private
-     * @name InitConfig
-     * @memberof Core.UI.Autocomplete
-     * @function
-     * @return {Object} The autocompletion config.
-     * @param {String} Type - Type of config, e.g. "CustomerSearch.
-     * @param {String} Options - Autocompletion config options.
-     * @description
-     *      Gets the needed config options object.
-     */
     function InitConfig(Type, Options) {
         var TypeConfig = Core.Config.Get('Autocomplete');
 
@@ -99,77 +56,32 @@ Core.UI.Autocomplete = (function (TargetNS) {
         return Config;
     }
 
-    // Override the autocomplete render function to highlight the part of the match
-    // which matches the search term.
-    $.ui.autocomplete.prototype._renderItem = function(ul, item) {
-
-        var Regex = new RegExp("(" + this.term.replace(/[-[\]/{}()*+?.\\^$|]/g, "\\$&") + ")", "i"),
-            Label = item.label;
-
-        // Use not HTML for now, due next action will escape special HTML characters.
-        Label = Label.replace(Regex, "OPENSTRONGTAG$1CLOSESTRONGTAG");
-
-        Label = Core.App.EscapeHTML(Label);
-
-        // Replace dummy tags with corresponding HTML.
-        Label = Label.replace("OPENSTRONGTAG", '<strong>');
-        Label = Label.replace("CLOSESTRONGTAG", '</strong>');
-
-        return $('<li></li>')
-            .data('item.autocomplete', item)
-            .append('<a href="#">' + Label + '</a>')
-            .appendTo(ul);
-     };
-
-    /**
-     * @name GetConfig
-     * @memberof Core.UI.Autocomplete
-     * @function
-     * @return {Object} Config option value.
-     * @param {String} Key - The config option name.
-     * @description
-     *      gets the config value of a specific key.
-     */
     TargetNS.GetConfig = function(Key) {
         return Config[Key];
     };
 
-    /**
-     * @name SearchButtonClicked
-     * @memberof Core.UI.Autocomplete
-     * @member {Object}
-     * @description
-     *      Needed for the handling of searches with ActiveAutoComplete = 0.
-     */
+    // Needed for the handling of searches with ActiveAutoComplete = 0
     TargetNS.SearchButtonClicked = {};
 
     /**
-     * @callback Core.UI.Autocomplete~SourceFunction
-     * @returns {Array}  Data collected for autocompletion, every array element is an object with label and value keys.
-     * @param {String} Request - The data provided by the autocomplete (e.g. the entered text).
-     * @param {Function} Response - The function defined by the autocomplete to call with the selected data.
-     */
-
-    /**
-     * @callback Core.UI.Autocomplete~SelectFunction
-     * @param {EventObject} Event - The original browser event object.
-     * @param {Object} UI - The data given from the UI (e.g. UI.item is the selected autocomplete list item).
-     */
-
-    /**
-     * @name Init
-     * @memberof Core.UI.Autocomplete
      * @function
-     * @param {jQueryObject} $Element - The element which gets autocomplete infos.
-     * @param {Core.UI.Autocomplete~SourceFunction} SourceFunction - Defines the source data for the autocomplete.
-     * @param {Core.UI.Autocomplete~SelectFunction} SelectFunction - Is executed, if an entry is selected.
-     * @param {String} Type of autocompletion, e.g. "CustomerSearch" etc.
-     * @param {Object} Options object data with autocomplete plugin options
      * @description
      *      This function initializes autocomplete on an input element.
+     * @param {jQueryObject} $Element which gets autocomplete infos.
+     * @param {Function} SourceFunction defines the source data for the autocomplete
+     *              Two params: Request and Response
+     *                      Request: the data provided by the autocomplete (e.g. the entered text)
+     *                      Response: the function defined by the autocomplete to call with the selected data
+     * @param {Function} SelectFunction is executed, if an entry is selected
+     *              Two params: Event and UI
+     *                      Event: the original browser event object
+     *                      UI: the data given from the UI (e.g. UI.item is the selected autocomplete list item)
+     * @param {String} Type of autocompletion, e.g. "CustomerSearch" etc.
+     * @param {Object} Options object data with autocomplete plugin options
+     * @return nothing
      */
     TargetNS.Init = function ($Element, SourceFunction, SelectFunction, Type, Options) {
-        var AutocompleteConfig,
+        var Config,
             $Loader;
 
         // Only start autocompletion, if $Element is valid element
@@ -177,38 +89,30 @@ Core.UI.Autocomplete = (function (TargetNS) {
             return;
         }
 
-        AutocompleteConfig = InitConfig(Type, Options);
+        Config = InitConfig(Type, Options);
 
         $Element.each(function () {
-
             var $SingleElement = $(this);
-
-            $(this).data('request-counter', 0);
-
             $SingleElement.autocomplete({
-                minLength: AutocompleteConfig.MinQueryLength,
-                delay: AutocompleteConfig.QueryDelay,
+                minLength: Config.MinQueryLength,
+                delay: Config.QueryDelay,
                 search: function() {
                     var FieldID = $SingleElement.attr('id'),
                         LoaderHTML = '<span id="' + AJAXLoaderPrefix + FieldID + '" class="AJAXLoader"></span>';
 
-                    $Loader = $('#' + AJAXLoaderPrefix + Core.App.EscapeSelector(FieldID));
+                    $Loader = $('#' + AJAXLoaderPrefix + FieldID);
 
                     if (!$Loader.length) {
                         $SingleElement.after(LoaderHTML);
-                        $Loader = $('#' + AJAXLoaderPrefix + Core.App.EscapeSelector(FieldID));
+                        $Loader = $('#' + AJAXLoaderPrefix + FieldID);
+                    }
+                    else {
+                        $Loader.show();
                     }
-
-                    $SingleElement.data('request-counter', parseInt($SingleElement.data('request-counter'), 10) + 1);
-
-                    $Loader.show();
                 },
                 response: function() {
-                    // remove loader again if there are no results
-                    $SingleElement.data('request-counter', parseInt($SingleElement.data('request-counter'), 10) - 1);
-                    if (parseInt($SingleElement.data('request-counter'), 10) <= 0) {
-                        $Loader.hide();
-                    }
+                    // remove loader again
+                    $Loader.hide();
                 },
                 open: function() {
                     // force a higher z-index than the overlay/dialog
@@ -256,7 +160,7 @@ Core.UI.Autocomplete = (function (TargetNS) {
             });
         });
 
-        if (!AutocompleteConfig.AutoCompleteActive) {
+        if (!Config.AutoCompleteActive) {
             $Element.each(function () {
                 var $SelectedElement = $(this);
                 $SelectedElement.after('<button id="' + Core.App.EscapeSelector($SelectedElement.attr('id')) + 'Search" type="button">' + Config.ButtonText + '</button>');
